use anchor_lang::prelude::*;

pub const SEED_INDEX: &[u8] = b"idx";

#[account]
pub struct Index {
    pub owner: Pubkey,
    pub namespace: String,
    pub item_count: u128,
    pub bump: u8,
}
